==> postmarketos-tweaks-0.13.1-1-any.pkg.tar.zst: usr/share/pmos-tweaks/pmos_tweaks/cpus.py <==
arm_implementer = {
    65: "ARM",
    66: "Broadcom",
    67: "Cavium",
    68: "DEC",
    78: "nVidia",
    80: "APM",
    81: "Qualcomm",
    83: "Samsung",
    84: "Texas Instruments",
    86: "Marvell",
    102: "Faraday",
    105: "Intel",
}

arm_part = {
    65: {
        2064: "ARM810",
        2336: "ARM920",
        2338: "ARM922",
        2342: "ARM926",
        2368: "ARM940",
        2374: "ARM946",
        2406: "ARM966",
        2592: "ARM1020",
        2594: "ARM1022",
        2598: "ARM1026",
        2818: "ARM11 MPCore",
        2870: "ARM1136",
        2902: "ARM1156",
        2934: "ARM1176",
        3077: "Cortex-A5",
        3079: "Cortex-A7",
        3080: "Cortex-A8",
        3081: "Cortex-A9",
        3085: "Cortex-A17 ",
        3087: "Cortex-A15",
        3086: "Cortex-A17",
        3092: "Cortex-R4",
        3093: "Cortex-R5",
        3095: "Cortex-R7",
        3096: "Cortex-R8",
        3104: "Cortex-M0",
        3105: "Cortex-M1",
        3107: "Cortex-M3",
        3108: "Cortex-M4",
        3111: "Cortex-M7",
        3168: "Cortex-M0+",
        3329: "Cortex-A32",
        3331: "Cortex-A53",
        3332: "Cortex-A35",
        3333: "Cortex-A55",
        3335: "Cortex-A57",
        3336: "Cortex-A72",
        3337: "Cortex-A73",
        3338: "Cortex-A75",
        3339: "Cortex-A76",
        3340: "Neoverse-N1",
        3341: "Cortex-A77",
        3347: "Cortex-R52",
        3360: "Cortex-M23",
        3361: "Cortex-M33",
        3402: "Neoverse-E1",
    },
    66: {
        15: "Brahma B15",
        256: "Brahma B53",
        1302: "ThunderX2",
    },
    67: {
        160: "ThunderX",
        161: "ThunderX 88XX",
        162: "ThunderX 81XX",
        163: "ThunderX 83XX",
        175: "ThunderX2 99xx",
    },
    68: {
        2576: "SA110",
        2577: "SA1100",
    },
    78: {
        0: "Denver",
        3: "Denver 2",
    },
    80: {
        0: "X-Gene",
    },
    81: {
        15: "Scorpion",
        45: "Scorpion",
        77: "Krait",
        111: "Krait",
        513: "Kryo",
        517: "Kryo",
        529: "Kryo",
        2048: "Falkor V1/Kryo",
        2049: "Kryo V2",
        2050: "Kryo 3xx gold",
        2051: "Kryo 3xx silver",
        2053: "Kryo 5xx silver",
        3072: "Falkor",
        3073: "Saphira",
    },
    83: {
        1: "exynos-m1",
    },
    84: {
    },
    86: {
        305: "Feroceon 88FR131",
        1409: "PJ4/PJ4b",
        1412: "PJ4B-MP",
    },
    102: {
        1318: "FA526",
        1574: "FA626",
    },
    105: {
        512: "i80200",
        528: "PXA250A",
        530: "PXA210A",
        578: "i80321-400",
        579: "i80321-600",
        656: "PXA250B/PXA26x",
        658: "PXA210B",
        706: "i80321-400-B0",
        707: "i80321-600-B0",
        720: "PXA250C/PXA255/PXA26x",
        722: "PXA210C",
        739: "i80219",
        1041: "PXA27x",
        1052: "IPX425-533",
        1053: "IPX425-400",
        1055: "IPX425-266",
        1666: "PXA32x",
        1667: "PXA930/PXA935",
        1672: "PXA30x",
        1673: "PXA31x",
        2833: "SA1110",
        3090: "IPX1200",
    },
}

==> postmarketos-tweaks-0.13.2-1-any.pkg.tar.zst: usr/share/pmos-tweaks/pmos_tweaks/cpus.py <==
arm_implementer = {
    65: "ARM",
    66: "Broadcom",
    67: "Cavium",
    68: "DEC",
    78: "nVidia",
    80: "APM",
    81: "Qualcomm",
    83: "Samsung",
    84: "Texas Instruments",
    86: "Marvell",
    102: "Faraday",
    105: "Intel",
}

arm_part = {
    65: {
        2064: "ARM810",
        2336: "ARM920",
        2338: "ARM922",
        2342: "ARM926",
        2368: "ARM940",
        2374: "ARM946",
        2406: "ARM966",
        2592: "ARM1020",
        2594: "ARM1022",
        2598: "ARM1026",
        2818: "ARM11 MPCore",
        2870: "ARM1136",
        2902: "ARM1156",
        2934: "ARM1176",
        3077: "Cortex-A5",
        3079: "Cortex-A7",
        3080: "Cortex-A8",
        3081: "Cortex-A9",
        3085: "Cortex-A17 ",
        3087: "Cortex-A15",
        3086: "Cortex-A17",
        3092: "Cortex-R4",
        3093: "Cortex-R5",
        3095: "Cortex-R7",
        3096: "Cortex-R8",
        3104: "Cortex-M0",
        3105: "Cortex-M1",
        3107: "Cortex-M3",
        3108: "Cortex-M4",
        3111: "Cortex-M7",
        3168: "Cortex-M0+",
        3329: "Cortex-A32",
        3331: "Cortex-A53",
        3332: "Cortex-A35",
        3333: "Cortex-A55",
        3335: "Cortex-A57",
        3336: "Cortex-A72",
        3337: "Cortex-A73",
        3338: "Cortex-A75",
        3339: "Cortex-A76",
        3340: "Neoverse-N1",
        3341: "Cortex-A77",
        3347: "Cortex-R52",
        3360: "Cortex-M23",
        3361: "Cortex-M33",
        3392: "Neoverse-V1",
        3393: "Cortex-A78",
        3394: "Cortex-A78AE",
        3396: "Cortex-X1",
        3398: "Cortex-A510",
        3399: "Cortex-A710",
        3400: "Cortex-X2",
        3401: "Neoverse-N2",
        3402: "Neoverse-E1",
        3403: "Cortex-A78C",
        3405: "Cortex-A715",
    },
    66: {
        15: "Brahma B15",
        256: "Brahma B53",
        1302: "ThunderX2",
    },
    67: {
        160: "ThunderX",
        161: "ThunderX 88XX",
        162: "ThunderX 81XX",
        163: "ThunderX 83XX",
        175: "ThunderX2 99xx",
    },
    68: {
        2576: "SA110",
        2577: "SA1100",
    },
    78: {
        0: "Denver",
        3: "Denver 2",
    },
    80: {
        0: "X-Gene",
    },
    81: {
        15: "Scorpion",
        45: "Scorpion",
        77: "Krait",
        111: "Krait",
        513: "Kryo",
        517: "Kryo",
        529: "Kryo",
        2048: "Falkor V1/Kryo",
        2049: "Kryo V2",
        2050: "Kryo 3xx gold",
        2051: "Kryo 3xx silver",
        2052: "Kryo 4xx/5xx gold",
        2053: "Kryo 4xx/5xx silver",
        3072: "Falkor",
        3073: "Saphira",
    },
    83: {
        1: "exynos-m1",
    },
    84: {
    },
    86: {
        305: "Feroceon 88FR131",
        1409: "PJ4/PJ4b",
        1412: "PJ4B-MP",
    },
    102: {
        1318: "FA526",
        1574: "FA626",
    },
    105: {
        512: "i80200",
        528: "PXA250A",
        530: "PXA210A",
        578: "i80321-400",
        579: "i80321-600",
        656: "PXA250B/PXA26x",
        658: "PXA210B",
        706: "i80321-400-B0",
        707: "i80321-600-B0",
        720: "PXA250C/PXA255/PXA26x",
        722: "PXA210C",
        739: "i80219",
        1041: "PXA27x",
        1052: "IPX425-533",
        1053: "IPX425-400",
        1055: "IPX425-266",
        1666: "PXA32x",
        1667: "PXA930/PXA935",
        1672: "PXA30x",
        1673: "PXA31x",
        2833: "SA1110",
        3090: "IPX1200",
    },
}
